@@ -16,7 +16,7 @@ def runtests(suite, verbosity):
 def get_option_parser():
     parser = optparse.OptionParser()
     basic = optparse.OptionGroup(parser, 'Basic test options')
-    basic.add_option('-e', '--engine', dest='engine', default='sqlite', help='Database engine to test, one of [sqlite3, postgres, mysql]')
+    basic.add_option('-e', '--engine', dest='engine', help='Database engine to test, one of [sqlite, postgres, mysql]')
     basic.add_option('-v', '--verbosity', dest='verbosity', default=1, type='int', help='Verbosity of output')
 
     suite = optparse.OptionGroup(parser, 'Simple test suite options')
@@ -30,8 +30,10 @@ def get_option_parser():
     cases.add_option('--gfk', dest='gfk', default=False, action='store_true', help='gfk tests')
     cases.add_option('--kv', dest='kv', default=False, action='store_true', help='key/value store tests')
     cases.add_option('--migrations', dest='migrations', default=False, action='store_true', help='migration helper tests (requires psycopg2)')
+    cases.add_option('--pool', dest='pool', default=False, action='store_true', help='connection pool tests')
     cases.add_option('--postgres-ext', dest='postgres_ext', default=False, action='store_true', help='postgres_ext tests (requires psycopg2)')
     cases.add_option('--pwiz', dest='pwiz', default=False, action='store_true', help='pwiz, schema introspector and model generator')
+    cases.add_option('--read-slave', dest='read_slave', default=False, action='store_true', help='read_slave tests')
     cases.add_option('--signals', dest='signals', default=False, action='store_true', help='signals tests')
     cases.add_option('--shortcuts', dest='shortcuts', default=False, action='store_true', help='shortcuts tests')
     cases.add_option('--sqlite-ext', dest='sqlite_ext', default=False, action='store_true', help='sqlite_ext tests')
@@ -66,6 +68,12 @@ def collect_modules(options):
             modules.append(tests_migrate)
         except ImportError:
             print_('Unable to import migration tests, skipping')
+    if xtra(options.pool):
+        try:
+            from playhouse import tests_pool
+            modules.append(tests_pool)
+        except ImportError:
+            print_('Unable to import connection pool tests, skipping')
     if xtra(options.postgres_ext):
         try:
             from playhouse import tests_postgres
@@ -75,6 +83,9 @@ def collect_modules(options):
     if xtra(options.pwiz):
         from playhouse import tests_pwiz
         modules.append(tests_pwiz)
+    if xtra(options.read_slave):
+        from playhouse import tests_read_slave
+        modules.append(tests_read_slave)
     if xtra(options.signals):
         from playhouse import tests_signals
         modules.append(tests_signals)
@@ -100,7 +111,8 @@ if __name__ == '__main__':
     parser = get_option_parser()
     options, args = parser.parse_args()
 
-    os.environ['PEEWEE_TEST_BACKEND'] = options.engine
+    if options.engine:
+        os.environ['PEEWEE_TEST_BACKEND'] = options.engine
     os.environ['PEEWEE_TEST_VERBOSITY'] = str(options.verbosity)
 
     from peewee import print_
